@@ -1,8 +1,12 @@
+import tempfile
 from .process import sagemaker_processing_run
 from .args import sagemaker_processing_args
-from argparse import ArgumentParser
+from argparse import ArgumentParser, Namespace
 import inspect
 from ..commands import Command, run_command
+from .config import SageMakerProcessingConfig
+from sagemaker.s3 import S3Uploader
+from ..session import sagemaker_session
 
 
 class ProcessingCommand(Command):
@@ -36,6 +40,18 @@ class ProcessingCommand(Command):
         )
 
 
+def sagemaker_processing_local_args(args, config: SageMakerProcessingConfig):
+    argv = vars(args)
+    tmps = {}
+    uris = {}
+    for k, v in config.outputs.items():
+        if argv[k] and argv[k].startswith("s3://"):
+            tmps[k] = tempfile.TemporaryDirectory()
+            uris[k] = argv[k]
+            argv[k] = tmps[k].__enter__()
+    return Namespace(**argv), tmps, uris
+
+
 def sagemaker_processing_handle(
     args, config, main
 ):
@@ -47,7 +63,21 @@ def sagemaker_processing_handle(
         )
     else:
         # Local processing
-        main(args)
+        args, tmps, uris = sagemaker_processing_local_args(
+            args=args, config=config)
+        try:
+            main(args)
+            if tmps:
+                session = sagemaker_session(profile_name=args.sagemaker_profile)
+                for k in tmps.keys():
+                    S3Uploader.upload(
+                        local_path=getattr(args, k),
+                        desired_s3_uri=uris[k],
+                        sagemaker_session=session
+                    )
+        finally:
+            for tmp in tmps.values():
+                tmp.__exit__()
 
 
 def sagemaker_processing_main(
